@@ -1,5 +1,5 @@
 #Load data with hidden/excluded assays (all NPX=NA)
-load(file = '../data/npx_data_format221010.RData')
+load(file = test_path('data','npx_data_format221010.RData'))
 npx_Check <- suppressWarnings(npxCheck(npx_data_format221010))
 npx_data_format <- npx_data_format221010 %>%
   filter(OlinkID %in% c(npx_Check$all_nas[1:5],"OID30538", "OID30550", "OID30519"))
