@@ -1,8 +1,8 @@
 skip_if_not_installed("ggplot2", minimum_version = "3.4.0")
 
 #Load data with hidden/excluded assays (all NPX=NA)
-load(file = '../data/npx_data_format221010.RData')
-load(file = '../data/npx_data_format221121.RData')
+load(file = test_path('data','npx_data_format221010.RData'))
+load(file = test_path('data','npx_data_format221121.RData'))
 
 sampleSubset <- c('A1', 'A10', 'A11', 'A12', 'A13', 'A14', 'B79', 'B8', 'B9') #To keep the file size down
 distribution_plot <- npx_data1 %>%
